==> icons_plus-1.0.0.tar.gz: lib/src/flag_icons.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

class FlagIcon extends SvgPicture {
  final String? flagName;
  FlagIcon(this.flagName,
      {double? size = 35.0,
      Color? color,
      BlendMode? colorBlendMode = BlendMode.srcIn})
      : super.asset(flagName!,
            package: 'icons_plus',
            height: size,
            colorBlendMode: colorBlendMode!,
            color: color);
}

class FlagIcons {
  static const abkhazia = "assets/flags/abkhazia.svg";
  static const afghanistan = "assets/flags/afghanistan.svg";
  static const african = "assets/flags/african.svg";
  static const aland_islands = "assets/flags/aland-islands.svg";
  static const albania = "assets/flags/albania.svg";
  static const algeria = "assets/flags/algeria.svg";
  static const american_samoa = "assets/flags/american-samoa.svg";
  static const andorra = "assets/flags/andorra.svg";
  static const angola = "assets/flags/angola.svg";
  static const anguilla = "assets/flags/anguilla.svg";
  static const antigua_and_barbuda = "assets/flags/antigua-and-barbuda.svg";
  static const argentina = "assets/flags/argentina.svg";
  static const armenia = "assets/flags/armenia.svg";
  static const aruba = "assets/flags/aruba.svg";
  static const australia = "assets/flags/australia.svg";
  static const austria = "assets/flags/austria.svg";
  static const azerbaijan = "assets/flags/azerbaijan.svg";
  static const azores_islands = "assets/flags/azores-islands.svg";
  static const bahamas = "assets/flags/bahamas.svg";
  static const bahrain = "assets/flags/bahrain.svg";
  static const balearic_islands = "assets/flags/balearic-islands.svg";
  static const bangladesh = "assets/flags/bangladesh.svg";
  static const barbados = "assets/flags/barbados.svg";
  static const basque_country = "assets/flags/basque-country.svg";
  static const belarus = "assets/flags/belarus.svg";
  static const belgium = "assets/flags/belgium.svg";
  static const belize = "assets/flags/belize.svg";
  static const benin = "assets/flags/benin.svg";
  static const bermuda = "assets/flags/bermuda.svg";
  static const bhutan = "assets/flags/bhutan.svg";
  static const bolivia = "assets/flags/bolivia.svg";
  static const bonaire = "assets/flags/bonaire.svg";
  static const bosnia_and_herzegovina = "assets/flags/bosnia-and-herzegovina.svg";
  static const botswana = "assets/flags/botswana.svg";
  static const brazil = "assets/flags/brazil.svg";
  static const british_columbia = "assets/flags/british-columbia.svg";
  static const british_indian_ocean_territory =
      "assets/flags/british-indian-ocean-territory.svg";
  static const british_virgin_islands = "assets/flags/british-virgin-islands.svg";
  static const brunei = "assets/flags/brunei.svg";
  static const bulgaria = "assets/flags/bulgaria.svg";
  static const burkina_faso = "assets/flags/burkina-faso.svg";
  static const burundi = "assets/flags/burundi.svg";
  static const cambodia = "assets/flags/cambodia.svg";
  static const cameroon = "assets/flags/cameroon.svg";
  static const canada = "assets/flags/canada.svg";
  static const canary_islands = "assets/flags/canary-islands.svg";
  static const cape_verde = "assets/flags/cape-verde.svg";
  static const cayman_islands = "assets/flags/cayman-islands.svg";
  static const central_african_republic = "assets/flags/central-african-republic.svg";
  static const ceuta = "assets/flags/ceuta.svg";
  static const chad = "assets/flags/chad.svg";
  static const chile = "assets/flags/chile.svg";
  static const china = "assets/flags/china.svg";
  static const christmas_island = "assets/flags/christmas-island.svg";
  static const cocos_island = "assets/flags/cocos-island.svg";
  static const colombia = "assets/flags/colombia.svg";
  static const comoros = "assets/flags/comoros.svg";
  static const cook_islands = "assets/flags/cook-islands.svg";
  static const corsica = "assets/flags/corsica.svg";
  static const costa_rica = "assets/flags/costa-rica.svg";
  static const croatia = "assets/flags/croatia.svg";
  static const cuba = "assets/flags/cuba.svg";
  static const curacao = "assets/flags/curacao.svg";
  static const cyprus = "assets/flags/cyprus.svg";
  static const czech_republic = "assets/flags/czech-republic.svg";
  static const democratic_republic_of_congo =
      "assets/flags/democratic-republic-of-congo.svg";
  static const denmark = "assets/flags/denmark.svg";
  static const djibouti = "assets/flags/djibouti.svg";
  static const dominica = "assets/flags/dominica.svg";
  static const dominican_republic = "assets/flags/dominican-republic.svg";
  static const east_timor = "assets/flags/east-timor.svg";
  static const ecuador = "assets/flags/ecuador.svg";
  static const egypt = "assets/flags/egypt.svg";
  static const el_salvador = "assets/flags/el-salvador.svg";
  static const england = "assets/flags/england.svg";
  static const equatorial_guinea = "assets/flags/equatorial-guinea.svg";
  static const eritrea = "assets/flags/eritrea.svg";
  static const estonia = "assets/flags/estonia.svg";
  static const ethiopia = "assets/flags/ethiopia.svg";
  static const european_union = "assets/flags/european-union.svg";
  static const falkland_islands = "assets/flags/falkland-islands.svg";
  static const faroe_islands = "assets/flags/faroe-islands.svg";
  static const fiji = "assets/flags/fiji.svg";
  static const finland = "assets/flags/finland.svg";
  static const france = "assets/flags/france.svg";
  static const french_polynesia = "assets/flags/french-polynesia.svg";
  static const gabon = "assets/flags/gabon.svg";
  static const galapagos_islands = "assets/flags/galapagos-islands.svg";
  static const gambia = "assets/flags/gambia.svg";
  static const georgia = "assets/flags/georgia.svg";
  static const germany = "assets/flags/germany.svg";
  static const ghana = "assets/flags/ghana.svg";
  static const gibraltar = "assets/flags/gibraltar.svg";
  static const greece = "assets/flags/greece.svg";
  static const greenland = "assets/flags/greenland.svg";
  static const grenada = "assets/flags/grenada.svg";
  static const guam = "assets/flags/guam.svg";
  static const guatemala = "assets/flags/guatemala.svg";
  static const guernsey = "assets/flags/guernsey.svg";
  static const guinea_bissau = "assets/flags/guinea-bissau.svg";
  static const guinea = "assets/flags/guinea.svg";
  static const haiti = "assets/flags/haiti.svg";
  static const hawaii = "assets/flags/hawaii.svg";
  static const honduras = "assets/flags/honduras.svg";
  static const hong_kong = "assets/flags/hong-kong.svg";
  static const hungary = "assets/flags/hungary.svg";
  static const iceland = "assets/flags/iceland.svg";
  static const india = "assets/flags/india.svg";
  static const indonesia = "assets/flags/indonesia.svg";
  static const iran = "assets/flags/iran.svg";
  static const iraq = "assets/flags/iraq.svg";
  static const ireland = "assets/flags/ireland.svg";
  static const isle_of_man = "assets/flags/isle-of-man.svg";
  static const israel = "assets/flags/israel.svg";
  static const italy = "assets/flags/italy.svg";
  static const ivory_coast = "assets/flags/ivory-coast.svg";
  static const jamaica = "assets/flags/jamaica.svg";
  static const japan = "assets/flags/japan.svg";
  static const jersey = "assets/flags/jersey.svg";
  static const jordan = "assets/flags/jordan.svg";
  static const kazakhstan = "assets/flags/kazakhstan.svg";
  static const kenya = "assets/flags/kenya.svg";
  static const kosovo = "assets/flags/kosovo.svg";
  static const kuwait = "assets/flags/kuwait.svg";
  static const kyrgyzstan = "assets/flags/kyrgyzstan.svg";
  static const laos = "assets/flags/laos.svg";
  static const latvia = "assets/flags/latvia.svg";
  static const lebanon = "assets/flags/lebanon.svg";
  static const lesotho = "assets/flags/lesotho.svg";
  static const liberia = "assets/flags/liberia.svg";
  static const libya = "assets/flags/libya.svg";
  static const liechtenstein = "assets/flags/liechtenstein.svg";
  static const lithuania = "assets/flags/lithuania.svg";
  static const luxembourg = "assets/flags/luxembourg.svg";
  static const macao = "assets/flags/macao.svg";
  static const madagascar = "assets/flags/madagascar.svg";
  static const madeira = "assets/flags/madeira.svg";
  static const malawi = "assets/flags/malawi.svg";
  static const malaysia = "assets/flags/malaysia.svg";
  static const maldives = "assets/flags/maldives.svg";
  static const mali = "assets/flags/mali.svg";
  static const malta = "assets/flags/malta.svg";
  static const marshall_island = "assets/flags/marshall-island.svg";
  static const martinique = "assets/flags/martinique.svg";
  static const mauritania = "assets/flags/mauritania.svg";
  static const mauritius = "assets/flags/mauritius.svg";
  static const melilla = "assets/flags/melilla.svg";
  static const mexico = "assets/flags/mexico.svg";
  static const micronesia = "assets/flags/micronesia.svg";
  static const moldova = "assets/flags/moldova.svg";
  static const monaco = "assets/flags/monaco.svg";
  static const mongolia = "assets/flags/mongolia.svg";
  static const montenegro = "assets/flags/montenegro.svg";
  static const montserrat = "assets/flags/montserrat.svg";
  static const morocco = "assets/flags/morocco.svg";
  static const mozambique = "assets/flags/mozambique.svg";
  static const myanmar = "assets/flags/myanmar.svg";
  static const namibia = "assets/flags/namibia.svg";
  static const nauru = "assets/flags/nauru.svg";
  static const nepal = "assets/flags/nepal.svg";
  static const netherlands = "assets/flags/netherlands.svg";
  static const new_zealand = "assets/flags/new-zealand.svg";
  static const nicaragua = "assets/flags/nicaragua.svg";
  static const niger = "assets/flags/niger.svg";
  static const nigeria = "assets/flags/nigeria.svg";
  static const niue = "assets/flags/niue.svg";
  static const norfolk_island = "assets/flags/norfolk-island.svg";
  static const north_korea = "assets/flags/north-korea.svg";
  static const northen_cyprus = "assets/flags/northen-cyprus.svg";
  static const northern_marianas_islands =
      "assets/flags/northern-marianas-islands.svg";
  static const norway = "assets/flags/norway.svg";
  static const oman = "assets/flags/oman.svg";
  static const orkney_islands = "assets/flags/orkney-islands.svg";
  static const ossetia = "assets/flags/ossetia.svg";
  static const otan = "assets/flags/otan.svg";
  static const pakistan = "assets/flags/pakistan.svg";
  static const palau = "assets/flags/palau.svg";
  static const palestine = "assets/flags/palestine.svg";
  static const panama = "assets/flags/panama.svg";
  static const papua_new_guinea = "assets/flags/papua-new-guinea.svg";
  static const paraguay = "assets/flags/paraguay.svg";
  static const peru = "assets/flags/peru.svg";
  static const philippines = "assets/flags/philippines.svg";
  static const pitcairn_islands = "assets/flags/pitcairn-islands.svg";
  static const poland = "assets/flags/poland.svg";
  static const portugal = "assets/flags/portugal.svg";
  static const puerto_rico = "assets/flags/puerto-rico.svg";
  static const qatar = "assets/flags/qatar.svg";
  static const rapa_nui = "assets/flags/rapa-nui.svg";
  static const republic_of_macedonia = "assets/flags/republic-of-macedonia.svg";
  static const republic_of_the_congo = "assets/flags/republic-of-the-congo.svg";
  static const romania = "assets/flags/romania.svg";
  static const russia = "assets/flags/russia.svg";
  static const rwanda = "assets/flags/rwanda.svg";
  static const saba_island = "assets/flags/saba-island.svg";
  static const sahrawi_arab_democratic_republic =
      "assets/flags/sahrawi-arab-democratic-republic.svg";
  static const saint_kitts_and_nevis = "assets/flags/saint-kitts-and-nevis.svg";
  static const samoa = "assets/flags/samoa.svg";
  static const san_marino = "assets/flags/san-marino.svg";
  static const sao_tome_and_principe = "assets/flags/sao-tome-and-principe.svg";
  static const sardinia = "assets/flags/sardinia.svg";
  static const saudi_arabia = "assets/flags/saudi-arabia.svg";
  static const scotland = "assets/flags/scotland.svg";
  static const senegal = "assets/flags/senegal.svg";
  static const serbia = "assets/flags/serbia.svg";
  static const seychelles = "assets/flags/seychelles.svg";
  static const sicily = "assets/flags/sicily.svg";
  static const sierra_leone = "assets/flags/sierra-leone.svg";
  static const singapore = "assets/flags/singapore.svg";
  static const sint_eustatius = "assets/flags/sint-eustatius.svg";
  static const sint_maarten = "assets/flags/sint-maarten.svg";
  static const slovakia = "assets/flags/slovakia.svg";
  static const slovenia = "assets/flags/slovenia.svg";
  static const solomon_islands = "assets/flags/solomon-islands.svg";
  static const somalia = "assets/flags/somalia.svg";
  static const somaliland = "assets/flags/somaliland.svg";
  static const south_africa = "assets/flags/south-africa.svg";
  static const south_korea = "assets/flags/south-korea.svg";
  static const south_sudan = "assets/flags/south-sudan.svg";
  static const spain = "assets/flags/spain.svg";
  static const sri_lanka = "assets/flags/sri-lanka.svg";
  static const st_barts = "assets/flags/st-barts.svg";
  static const st_vincent_and_the_grenadines =
      "assets/flags/st-vincent-and-the-grenadines.svg";
  static const sudan = "assets/flags/sudan.svg";
  static const suriname = "assets/flags/suriname.svg";
  static const sweden = "assets/flags/sweden.svg";
  static const switzerland = "assets/flags/switzerland.svg";
  static const syria = "assets/flags/syria.svg";
  static const taiwan = "assets/flags/taiwan.svg";
  static const tajikistan = "assets/flags/tajikistan.svg";
  static const tanzania = "assets/flags/tanzania.svg";
  static const thailand = "assets/flags/thailand.svg";
  static const tibet = "assets/flags/tibet.svg";
  static const togo = "assets/flags/togo.svg";
  static const tokelau = "assets/flags/tokelau.svg";
  static const tonga = "assets/flags/tonga.svg";
  static const transnistria = "assets/flags/transnistria.svg";
  static const trinidad_and_tobago = "assets/flags/trinidad-and-tobago.svg";
  static const tubalu = "assets/flags/tubalu.svg";
  static const tunisia = "assets/flags/tunisia.svg";
  static const turkey = "assets/flags/turkey.svg";
  static const turkmenistan = "assets/flags/turkmenistan.svg";
  static const turks_and_caicos = "assets/flags/turks-and-caicos.svg";
  static const uganda = "assets/flags/uganda.svg";
  static const ukraine = "assets/flags/ukraine.svg";
  static const united_arab_emirates = "assets/flags/united-arab-emirates.svg";
  static const united_kingdom = "assets/flags/united-kingdom.svg";
  static const united_nations = "assets/flags/united-nations.svg";
  static const united_states_of_america = "assets/flags/united-states-of-america.svg";
  static const uruguay = "assets/flags/uruguay.svg";
  static const uzbekistan = "assets/flags/uzbekistan.svg";
  static const vanuatu = "assets/flags/vanuatu.svg";
  static const vatican_city = "assets/flags/vatican-city.svg";
  static const venezuela = "assets/flags/venezuela.svg";
  static const vietnam = "assets/flags/vietnam.svg";
  static const virgin_islands = "assets/flags/virgin-islands.svg";
  static const wales = "assets/flags/wales.svg";
  static const yemen = "assets/flags/yemen.svg";
  static const zambia = "assets/flags/zambia.svg";
  static const zimbabwe = "assets/flags/zimbabwe.svg";
}

==> icons_plus-1.0.2.tar.gz: lib/src/flag_icons.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';

///[SvgPicture] is basically used for read svg files
class FlagIcon extends SvgPicture {
  final String? flagName;

  FlagIcon(this.flagName,
      {double? size = 35.0,
      Color? color,
      BlendMode? colorBlendMode = BlendMode.srcIn})
      : super.asset(
          flagName!,
          package: 'icons_plus',
          height: size,
          colorBlendMode: colorBlendMode!,
          color: color,
        );
}

///[FlagIcons] is a class you can use to access more the 260 flag icons.
class FlagIcons {
  static const abkhazia = "assets/flags/abkhazia.svg";
  static const afghanistan = "assets/flags/afghanistan.svg";
  static const african = "assets/flags/african.svg";
  static const aland_islands = "assets/flags/aland-islands.svg";
  static const albania = "assets/flags/albania.svg";
  static const algeria = "assets/flags/algeria.svg";
  static const american_samoa = "assets/flags/american-samoa.svg";
  static const andorra = "assets/flags/andorra.svg";
  static const angola = "assets/flags/angola.svg";
  static const anguilla = "assets/flags/anguilla.svg";
  static const antigua_and_barbuda = "assets/flags/antigua-and-barbuda.svg";
  static const argentina = "assets/flags/argentina.svg";
  static const armenia = "assets/flags/armenia.svg";
  static const aruba = "assets/flags/aruba.svg";
  static const australia = "assets/flags/australia.svg";
  static const austria = "assets/flags/austria.svg";
  static const azerbaijan = "assets/flags/azerbaijan.svg";
  static const azores_islands = "assets/flags/azores-islands.svg";
  static const bahamas = "assets/flags/bahamas.svg";
  static const bahrain = "assets/flags/bahrain.svg";
  static const balearic_islands = "assets/flags/balearic-islands.svg";
  static const bangladesh = "assets/flags/bangladesh.svg";
  static const barbados = "assets/flags/barbados.svg";
  static const basque_country = "assets/flags/basque-country.svg";
  static const belarus = "assets/flags/belarus.svg";
  static const belgium = "assets/flags/belgium.svg";
  static const belize = "assets/flags/belize.svg";
  static const benin = "assets/flags/benin.svg";
  static const bermuda = "assets/flags/bermuda.svg";
  static const bhutan = "assets/flags/bhutan.svg";
  static const bolivia = "assets/flags/bolivia.svg";
  static const bonaire = "assets/flags/bonaire.svg";
  static const bosnia_and_herzegovina =
      "assets/flags/bosnia-and-herzegovina.svg";
  static const botswana = "assets/flags/botswana.svg";
  static const brazil = "assets/flags/brazil.svg";
  static const british_columbia = "assets/flags/british-columbia.svg";
  static const british_indian_ocean_territory =
      "assets/flags/british-indian-ocean-territory.svg";
  static const british_virgin_islands =
      "assets/flags/british-virgin-islands.svg";
  static const brunei = "assets/flags/brunei.svg";
  static const bulgaria = "assets/flags/bulgaria.svg";
  static const burkina_faso = "assets/flags/burkina-faso.svg";
  static const burundi = "assets/flags/burundi.svg";
  static const cambodia = "assets/flags/cambodia.svg";
  static const cameroon = "assets/flags/cameroon.svg";
  static const canada = "assets/flags/canada.svg";
  static const canary_islands = "assets/flags/canary-islands.svg";
  static const cape_verde = "assets/flags/cape-verde.svg";
  static const cayman_islands = "assets/flags/cayman-islands.svg";
  static const central_african_republic =
      "assets/flags/central-african-republic.svg";
  static const ceuta = "assets/flags/ceuta.svg";
  static const chad = "assets/flags/chad.svg";
  static const chile = "assets/flags/chile.svg";
  static const china = "assets/flags/china.svg";
  static const christmas_island = "assets/flags/christmas-island.svg";
  static const cocos_island = "assets/flags/cocos-island.svg";
  static const colombia = "assets/flags/colombia.svg";
  static const comoros = "assets/flags/comoros.svg";
  static const cook_islands = "assets/flags/cook-islands.svg";
  static const corsica = "assets/flags/corsica.svg";
  static const costa_rica = "assets/flags/costa-rica.svg";
  static const croatia = "assets/flags/croatia.svg";
  static const cuba = "assets/flags/cuba.svg";
  static const curacao = "assets/flags/curacao.svg";
  static const cyprus = "assets/flags/cyprus.svg";
  static const czech_republic = "assets/flags/czech-republic.svg";
  static const democratic_republic_of_congo =
      "assets/flags/democratic-republic-of-congo.svg";
  static const denmark = "assets/flags/denmark.svg";
  static const djibouti = "assets/flags/djibouti.svg";
  static const dominica = "assets/flags/dominica.svg";
  static const dominican_republic = "assets/flags/dominican-republic.svg";
  static const east_timor = "assets/flags/east-timor.svg";
  static const ecuador = "assets/flags/ecuador.svg";
  static const egypt = "assets/flags/egypt.svg";
  static const el_salvador = "assets/flags/el-salvador.svg";
  static const england = "assets/flags/england.svg";
  static const equatorial_guinea = "assets/flags/equatorial-guinea.svg";
  static const eritrea = "assets/flags/eritrea.svg";
  static const estonia = "assets/flags/estonia.svg";
  static const ethiopia = "assets/flags/ethiopia.svg";
  static const european_union = "assets/flags/european-union.svg";
  static const falkland_islands = "assets/flags/falkland-islands.svg";
  static const faroe_islands = "assets/flags/faroe-islands.svg";
  static const fiji = "assets/flags/fiji.svg";
  static const finland = "assets/flags/finland.svg";
  static const france = "assets/flags/france.svg";
  static const french_polynesia = "assets/flags/french-polynesia.svg";
  static const gabon = "assets/flags/gabon.svg";
  static const galapagos_islands = "assets/flags/galapagos-islands.svg";
  static const gambia = "assets/flags/gambia.svg";
  static const georgia = "assets/flags/georgia.svg";
  static const germany = "assets/flags/germany.svg";
  static const ghana = "assets/flags/ghana.svg";
  static const gibraltar = "assets/flags/gibraltar.svg";
  static const greece = "assets/flags/greece.svg";
  static const greenland = "assets/flags/greenland.svg";
  static const grenada = "assets/flags/grenada.svg";
  static const guam = "assets/flags/guam.svg";
  static const guatemala = "assets/flags/guatemala.svg";
  static const guernsey = "assets/flags/guernsey.svg";
  static const guinea_bissau = "assets/flags/guinea-bissau.svg";
  static const guinea = "assets/flags/guinea.svg";
  static const haiti = "assets/flags/haiti.svg";
  static const hawaii = "assets/flags/hawaii.svg";
  static const honduras = "assets/flags/honduras.svg";
  static const hong_kong = "assets/flags/hong-kong.svg";
  static const hungary = "assets/flags/hungary.svg";
  static const iceland = "assets/flags/iceland.svg";
  static const india = "assets/flags/india.svg";
  static const indonesia = "assets/flags/indonesia.svg";
  static const iran = "assets/flags/iran.svg";
  static const iraq = "assets/flags/iraq.svg";
  static const ireland = "assets/flags/ireland.svg";
  static const isle_of_man = "assets/flags/isle-of-man.svg";
  static const israel = "assets/flags/israel.svg";
  static const italy = "assets/flags/italy.svg";
  static const ivory_coast = "assets/flags/ivory-coast.svg";
  static const jamaica = "assets/flags/jamaica.svg";
  static const japan = "assets/flags/japan.svg";
  static const jersey = "assets/flags/jersey.svg";
  static const jordan = "assets/flags/jordan.svg";
  static const kazakhstan = "assets/flags/kazakhstan.svg";
  static const kenya = "assets/flags/kenya.svg";
  static const kosovo = "assets/flags/kosovo.svg";
  static const kuwait = "assets/flags/kuwait.svg";
  static const kyrgyzstan = "assets/flags/kyrgyzstan.svg";
  static const laos = "assets/flags/laos.svg";
  static const latvia = "assets/flags/latvia.svg";
  static const lebanon = "assets/flags/lebanon.svg";
  static const lesotho = "assets/flags/lesotho.svg";
  static const liberia = "assets/flags/liberia.svg";
  static const libya = "assets/flags/libya.svg";
  static const liechtenstein = "assets/flags/liechtenstein.svg";
  static const lithuania = "assets/flags/lithuania.svg";
  static const luxembourg = "assets/flags/luxembourg.svg";
  static const macao = "assets/flags/macao.svg";
  static const madagascar = "assets/flags/madagascar.svg";
  static const madeira = "assets/flags/madeira.svg";
  static const malawi = "assets/flags/malawi.svg";
  static const malaysia = "assets/flags/malaysia.svg";
  static const maldives = "assets/flags/maldives.svg";
  static const mali = "assets/flags/mali.svg";
  static const malta = "assets/flags/malta.svg";
  static const marshall_island = "assets/flags/marshall-island.svg";
  static const martinique = "assets/flags/martinique.svg";
  static const mauritania = "assets/flags/mauritania.svg";
  static const mauritius = "assets/flags/mauritius.svg";
  static const melilla = "assets/flags/melilla.svg";
  static const mexico = "assets/flags/mexico.svg";
  static const micronesia = "assets/flags/micronesia.svg";
  static const moldova = "assets/flags/moldova.svg";
  static const monaco = "assets/flags/monaco.svg";
  static const mongolia = "assets/flags/mongolia.svg";
  static const montenegro = "assets/flags/montenegro.svg";
  static const montserrat = "assets/flags/montserrat.svg";
  static const morocco = "assets/flags/morocco.svg";
  static const mozambique = "assets/flags/mozambique.svg";
  static const myanmar = "assets/flags/myanmar.svg";
  static const namibia = "assets/flags/namibia.svg";
  static const nauru = "assets/flags/nauru.svg";
  static const nepal = "assets/flags/nepal.svg";
  static const netherlands = "assets/flags/netherlands.svg";
  static const new_zealand = "assets/flags/new-zealand.svg";
  static const nicaragua = "assets/flags/nicaragua.svg";
  static const niger = "assets/flags/niger.svg";
  static const nigeria = "assets/flags/nigeria.svg";
  static const niue = "assets/flags/niue.svg";
  static const norfolk_island = "assets/flags/norfolk-island.svg";
  static const north_korea = "assets/flags/north-korea.svg";
  static const northen_cyprus = "assets/flags/northen-cyprus.svg";
  static const northern_marianas_islands =
      "assets/flags/northern-marianas-islands.svg";
  static const norway = "assets/flags/norway.svg";
  static const oman = "assets/flags/oman.svg";
  static const orkney_islands = "assets/flags/orkney-islands.svg";
  static const ossetia = "assets/flags/ossetia.svg";
  static const otan = "assets/flags/otan.svg";
  static const pakistan = "assets/flags/pakistan.svg";
  static const palau = "assets/flags/palau.svg";
  static const palestine = "assets/flags/palestine.svg";
  static const panama = "assets/flags/panama.svg";
  static const papua_new_guinea = "assets/flags/papua-new-guinea.svg";
  static const paraguay = "assets/flags/paraguay.svg";
  static const peru = "assets/flags/peru.svg";
  static const philippines = "assets/flags/philippines.svg";
  static const pitcairn_islands = "assets/flags/pitcairn-islands.svg";
  static const poland = "assets/flags/poland.svg";
  static const portugal = "assets/flags/portugal.svg";
  static const puerto_rico = "assets/flags/puerto-rico.svg";
  static const qatar = "assets/flags/qatar.svg";
  static const rapa_nui = "assets/flags/rapa-nui.svg";
  static const republic_of_macedonia = "assets/flags/republic-of-macedonia.svg";
  static const republic_of_the_congo = "assets/flags/republic-of-the-congo.svg";
  static const romania = "assets/flags/romania.svg";
  static const russia = "assets/flags/russia.svg";
  static const rwanda = "assets/flags/rwanda.svg";
  static const saba_island = "assets/flags/saba-island.svg";
  static const sahrawi_arab_democratic_republic =
      "assets/flags/sahrawi-arab-democratic-republic.svg";
  static const saint_kitts_and_nevis = "assets/flags/saint-kitts-and-nevis.svg";
  static const samoa = "assets/flags/samoa.svg";
  static const san_marino = "assets/flags/san-marino.svg";
  static const sao_tome_and_principe = "assets/flags/sao-tome-and-principe.svg";
  static const sardinia = "assets/flags/sardinia.svg";
  static const saudi_arabia = "assets/flags/saudi-arabia.svg";
  static const scotland = "assets/flags/scotland.svg";
  static const senegal = "assets/flags/senegal.svg";
  static const serbia = "assets/flags/serbia.svg";
  static const seychelles = "assets/flags/seychelles.svg";
  static const sicily = "assets/flags/sicily.svg";
  static const sierra_leone = "assets/flags/sierra-leone.svg";
  static const singapore = "assets/flags/singapore.svg";
  static const sint_eustatius = "assets/flags/sint-eustatius.svg";
  static const sint_maarten = "assets/flags/sint-maarten.svg";
  static const slovakia = "assets/flags/slovakia.svg";
  static const slovenia = "assets/flags/slovenia.svg";
  static const solomon_islands = "assets/flags/solomon-islands.svg";
  static const somalia = "assets/flags/somalia.svg";
  static const somaliland = "assets/flags/somaliland.svg";
  static const south_africa = "assets/flags/south-africa.svg";
  static const south_korea = "assets/flags/south-korea.svg";
  static const south_sudan = "assets/flags/south-sudan.svg";
  static const spain = "assets/flags/spain.svg";
  static const sri_lanka = "assets/flags/sri-lanka.svg";
  static const st_barts = "assets/flags/st-barts.svg";
  static const st_vincent_and_the_grenadines =
      "assets/flags/st-vincent-and-the-grenadines.svg";
  static const sudan = "assets/flags/sudan.svg";
  static const suriname = "assets/flags/suriname.svg";
  static const sweden = "assets/flags/sweden.svg";
  static const switzerland = "assets/flags/switzerland.svg";
  static const syria = "assets/flags/syria.svg";
  static const taiwan = "assets/flags/taiwan.svg";
  static const tajikistan = "assets/flags/tajikistan.svg";
  static const tanzania = "assets/flags/tanzania.svg";
  static const thailand = "assets/flags/thailand.svg";
  static const tibet = "assets/flags/tibet.svg";
  static const togo = "assets/flags/togo.svg";
  static const tokelau = "assets/flags/tokelau.svg";
  static const tonga = "assets/flags/tonga.svg";
  static const transnistria = "assets/flags/transnistria.svg";
  static const trinidad_and_tobago = "assets/flags/trinidad-and-tobago.svg";
  static const tubalu = "assets/flags/tubalu.svg";
  static const tunisia = "assets/flags/tunisia.svg";
  static const turkey = "assets/flags/turkey.svg";
  static const turkmenistan = "assets/flags/turkmenistan.svg";
  static const turks_and_caicos = "assets/flags/turks-and-caicos.svg";
  static const uganda = "assets/flags/uganda.svg";
  static const ukraine = "assets/flags/ukraine.svg";
  static const united_arab_emirates = "assets/flags/united-arab-emirates.svg";
  static const united_kingdom = "assets/flags/united-kingdom.svg";
  static const united_nations = "assets/flags/united-nations.svg";
  static const united_states_of_america =
      "assets/flags/united-states-of-america.svg";
  static const uruguay = "assets/flags/uruguay.svg";
  static const uzbekistan = "assets/flags/uzbekistan.svg";
  static const vanuatu = "assets/flags/vanuatu.svg";
  static const vatican_city = "assets/flags/vatican-city.svg";
  static const venezuela = "assets/flags/venezuela.svg";
  static const vietnam = "assets/flags/vietnam.svg";
  static const virgin_islands = "assets/flags/virgin-islands.svg";
  static const wales = "assets/flags/wales.svg";
  static const yemen = "assets/flags/yemen.svg";
  static const zambia = "assets/flags/zambia.svg";
  static const zimbabwe = "assets/flags/zimbabwe.svg";
}
